package server

import "github.com/prometheus/client_golang/prometheus"

var (
	totalKeysInMemory = prometheus.NewGauge(prometheus.GaugeOpts{
		Name: "keystored_keys_total",
		Help: "Total number of unlocked keys in-memory.",
	})
	requestsCounter = prometheus.NewCounterVec(prometheus.CounterOpts{
		Name: "keystored_requests_total",
		Help: "Counter of requests by method and status.",
	}, []string{"method", "status"})
	decryptedKeysCounter = prometheus.NewCounter(prometheus.CounterOpts{
		Name: "keystored_decrypted_keys_total",
		Help: "Counter of decrypted keys.",
	})
	unlockedKeysServedCounter = prometheus.NewCounter(prometheus.CounterOpts{
		Name: "keystored_unlocked_keys_served_total",
		Help: "Counter of unlocked keys served.",
	})
)

func init() {
	prometheus.MustRegister(totalKeysInMemory)
	prometheus.MustRegister(requestsCounter)
	prometheus.MustRegister(decryptedKeysCounter)
	prometheus.MustRegister(unlockedKeysServedCounter)
}

func (s *KeyStore) updateKeyspaceSize() {
	totalKeysInMemory.Set(float64(len(s.userKeys)))
}
